![](https://cto.ai/static/sdk-banner.png)

# sdk-python

This is the Python version of The Ops Platform SDK. In
conjunction with our Docker base images, it allows the development of
automations with rich user interfaces, that run in both the local
terminal and in Slack. Other than the Ops Platform itself, this SDK
depends on:

- Python 3.6+
- The `requests` library, version 2+

## The Ops Platform

This SDK is designed to work in conjunction with The Ops
Platform. Please see <https://cto.ai/platform> for more details.

To build and publish Ops to The Ops Platform, you will need to use
The Ops CLI. Find installation instructions and reference
documentation at <https://cto.ai/docs>.
